@@ -1,6 +1,6 @@
 #Copyright (c) 2013 Will Harris
 # See the file license.txt for copying permission.
 
-from document import Document
-from builder import Builder
-import drafts
+from .builder import Builder
+from .document import Document
+from . import drafts
